@@ -78,14 +78,14 @@ foreach my $agent ( sort @agents ) {
 }
 snmp_dispatcher();
 
-# warn on errors during initialization
-foreach my $session (@sessions) {
-  if ( $session->errors ) {
-    foreach my $error ( $session->errors ) {
-      warn $session->hostname . ": $error\n";
-    }
-  }
-}
+# check for init errors
+$_->init_ok foreach @sessions;
+
+# remove sessions with error from the sessions list
+@sessions = grep {
+  if ( $_->errors ) { warn scalar $_->errors, "\n"; undef }
+  else              { 1 }
+} @sessions;
 
 # remove sessions with errors from the sessions list
 @sessions = grep { not $_->errors(1) } @sessions;
